==> kwavecontrol_0.4.2.orig.tar.gz: kwavecontrol-0.4.2/src/kinfowidget.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Matthias Reif                                   *
 *   matthias.reif@informatik.tu-chemnitz.de                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KINFOWIDGET_H
#define KINFOWIDGET_H

#include <qlabel.h>
#include <qpixmap.h>
#include "ksingletabwidget.h"
#include "kwavecontrol.h"

/**
	@author Matthias Reif
*/
class KInfoWidget : public QWidget
{
Q_OBJECT
public:
	KInfoWidget( QWidget *parent = 0, const char *name = 0 );
	~KInfoWidget();
	KSingleTabWidget* gridWidget;

protected:
	QLabel *logoLabel;
	void resizeEvent( QResizeEvent * );
};

#endif

==> kwavecontrol-0.4.3.tar.gz: kwavecontrol-0.4.3/src/kinfowidget.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Matthias Reif                                   *
 *   matthias.reif@informatik.tu-chemnitz.de                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KINFOWIDGET_H
#define KINFOWIDGET_H

#include <qlabel.h>
#include <qpixmap.h>
#include <qvbox.h>
#include <qhbox.h>
#include "ksingletabwidget.h"
#include "kwavecontrol.h"

/**
	@author Matthias Reif
*/
class KInfoWidget : public QVBox
{
Q_OBJECT
public:
	KInfoWidget( QWidget *parent = 0, const char *name = 0 );
	~KInfoWidget();
	KSingleTabWidget* gridWidget;
};

#endif
